summaryrefslogtreecommitdiffstats
path: root/kimgio
diff options
context:
space:
mode:
Diffstat (limited to 'kimgio')
-rw-r--r--kimgio/README2
-rw-r--r--kimgio/dds.cpp36
-rw-r--r--kimgio/exr.cpp2
-rw-r--r--kimgio/hdr.cpp4
-rw-r--r--kimgio/ico.cpp8
-rw-r--r--kimgio/jp2.cpp2
-rw-r--r--kimgio/pcx.cpp2
-rw-r--r--kimgio/pcx.h6
-rw-r--r--kimgio/rgb.cpp30
-rw-r--r--kimgio/tga.cpp4
-rw-r--r--kimgio/xcf.cpp40
-rw-r--r--kimgio/xcf.h6
-rw-r--r--kimgio/xview.cpp6
13 files changed, 74 insertions, 74 deletions
diff --git a/kimgio/README b/kimgio/README
index 142823e6c..8905d31a3 100644
--- a/kimgio/README
+++ b/kimgio/README
@@ -1,7 +1,7 @@
KDE Image I/O library
---------------------
This library allows applications that use the Qt library
-(i.e. QImageIO, QImage, QPixmap and friends) to read and
+(i.e. QImageIO, TQImage, QPixmap and friends) to read and
write images in extra formats. Current formats include:
JPEG <read> <write>
diff --git a/kimgio/dds.cpp b/kimgio/dds.cpp
index 22251002c..28e4f9110 100644
--- a/kimgio/dds.cpp
+++ b/kimgio/dds.cpp
@@ -294,7 +294,7 @@ namespace { // Private.
const uint h = header.height;
for( uint y = 0; y < h; y++ ) {
- QRgb * scanline = (QRgb *) img.scanLine( y );
+ TQRgb * scanline = (TQRgb *) img.scanLine( y );
for( uint x = 0; x < w; x++ ) {
uchar r, g, b, a;
s >> b >> g >> r >> a;
@@ -311,7 +311,7 @@ namespace { // Private.
const uint h = header.height;
for( uint y = 0; y < h; y++ ) {
- QRgb * scanline = (QRgb *) img.scanLine( y );
+ TQRgb * scanline = (TQRgb *) img.scanLine( y );
for( uint x = 0; x < w; x++ ) {
uchar r, g, b;
s >> b >> g >> r;
@@ -328,7 +328,7 @@ namespace { // Private.
const uint h = header.height;
for( uint y = 0; y < h; y++ ) {
- QRgb * scanline = (QRgb *) img.scanLine( y );
+ TQRgb * scanline = (TQRgb *) img.scanLine( y );
for( uint x = 0; x < w; x++ ) {
Color1555 color;
s >> color.u;
@@ -349,7 +349,7 @@ namespace { // Private.
const uint h = header.height;
for( uint y = 0; y < h; y++ ) {
- QRgb * scanline = (QRgb *) img.scanLine( y );
+ TQRgb * scanline = (TQRgb *) img.scanLine( y );
for( uint x = 0; x < w; x++ ) {
Color4444 color;
s >> color.u;
@@ -370,7 +370,7 @@ namespace { // Private.
const uint h = header.height;
for( uint y = 0; y < h; y++ ) {
- QRgb * scanline = (QRgb *) img.scanLine( y );
+ TQRgb * scanline = (TQRgb *) img.scanLine( y );
for( uint x = 0; x < w; x++ ) {
Color565 color;
s >> color.u;
@@ -524,11 +524,11 @@ namespace { // Private.
const uint h = header.height;
BlockDXT block;
- QRgb * scanline[4];
+ TQRgb * scanline[4];
for( uint y = 0; y < h; y += 4 ) {
for( uint j = 0; j < 4; j++ ) {
- scanline[j] = (QRgb *) img.scanLine( y + j );
+ scanline[j] = (TQRgb *) img.scanLine( y + j );
}
for( uint x = 0; x < w; x += 4 ) {
@@ -564,11 +564,11 @@ namespace { // Private.
BlockDXT block;
BlockDXTAlphaExplicit alpha;
- QRgb * scanline[4];
+ TQRgb * scanline[4];
for( uint y = 0; y < h; y += 4 ) {
for( uint j = 0; j < 4; j++ ) {
- scanline[j] = (QRgb *) img.scanLine( y + j );
+ scanline[j] = (TQRgb *) img.scanLine( y + j );
}
for( uint x = 0; x < w; x += 4 ) {
@@ -616,11 +616,11 @@ namespace { // Private.
BlockDXT block;
BlockDXTAlphaLinear alpha;
- QRgb * scanline[4];
+ TQRgb * scanline[4];
for( uint y = 0; y < h; y += 4 ) {
for( uint j = 0; j < 4; j++ ) {
- scanline[j] = (QRgb *) img.scanLine( y + j );
+ scanline[j] = (TQRgb *) img.scanLine( y + j );
}
for( uint x = 0; x < w; x += 4 ) {
@@ -671,11 +671,11 @@ namespace { // Private.
BlockDXT block;
BlockDXTAlphaLinear alpha;
- QRgb * scanline[4];
+ TQRgb * scanline[4];
for( uint y = 0; y < h; y += 4 ) {
for( uint j = 0; j < 4; j++ ) {
- scanline[j] = (QRgb *) img.scanLine( y + j );
+ scanline[j] = (TQRgb *) img.scanLine( y + j );
}
for( uint x = 0; x < w; x += 4 ) {
@@ -720,11 +720,11 @@ namespace { // Private.
BlockDXTAlphaLinear xblock;
BlockDXTAlphaLinear yblock;
- QRgb * scanline[4];
+ TQRgb * scanline[4];
for( uint y = 0; y < h; y += 4 ) {
for( uint j = 0; j < 4; j++ ) {
- scanline[j] = (QRgb *) img.scanLine( y + j );
+ scanline[j] = (TQRgb *) img.scanLine( y + j );
}
for( uint x = 0; x < w; x += 4 ) {
@@ -941,9 +941,9 @@ namespace { // Private.
// Copy face on the image.
for( uint y = 0; y < header.height; y++ ) {
- QRgb * src = (QRgb *) face.scanLine( y );
- QRgb * dst = (QRgb *) img.scanLine( y + offset_y ) + offset_x;
- memcpy( dst, src, sizeof(QRgb) * header.width );
+ TQRgb * src = (TQRgb *) face.scanLine( y );
+ TQRgb * dst = (TQRgb *) img.scanLine( y + offset_y ) + offset_x;
+ memcpy( dst, src, sizeof(TQRgb) * header.width );
}
}
diff --git a/kimgio/exr.cpp b/kimgio/exr.cpp
index 5332140fa..862d8237a 100644
--- a/kimgio/exr.cpp
+++ b/kimgio/exr.cpp
@@ -53,7 +53,7 @@ using namespace Imf;
* format into the normal 32 bit pixel format. Process is from the
* ILM code.
*/
-QRgb RgbaToQrgba(struct Rgba imagePixel)
+TQRgb RgbaToQrgba(struct Rgba imagePixel)
{
float r,g,b,a;
diff --git a/kimgio/hdr.cpp b/kimgio/hdr.cpp
index 5f1832f02..0749ce751 100644
--- a/kimgio/hdr.cpp
+++ b/kimgio/hdr.cpp
@@ -69,7 +69,7 @@ namespace { // Private.
}
- static void RGBE_To_QRgbLine(uchar * image, QRgb * scanline, int width)
+ static void RGBE_To_QRgbLine(uchar * image, TQRgb * scanline, int width)
{
for (int j = 0; j < width; j++)
{
@@ -108,7 +108,7 @@ namespace { // Private.
for (int cline = 0; cline < height; cline++)
{
- QRgb * scanline = (QRgb *) img.scanLine( cline );
+ TQRgb * scanline = (TQRgb *) img.scanLine( cline );
// determine scanline type
if ((width < MINELEN) || (MAXELEN < width))
diff --git a/kimgio/ico.cpp b/kimgio/ico.cpp
index e14f09fb5..35cef0282 100644
--- a/kimgio/ico.cpp
+++ b/kimgio/ico.cpp
@@ -169,9 +169,9 @@ namespace
if ( icon.isNull() ) return false;
icon.setAlphaBuffer( true );
- TQMemArray< QRgb > colorTable( paletteSize );
+ TQMemArray< TQRgb > colorTable( paletteSize );
- colorTable.fill( QRgb( 0 ) );
+ colorTable.fill( TQRgb( 0 ) );
for ( unsigned i = 0; i < paletteEntries; ++i )
{
unsigned char rgb[ 4 ];
@@ -188,7 +188,7 @@ namespace
{
stream.readRawBytes( reinterpret_cast< char* >( buf ), bpl );
unsigned char* pixel = buf;
- QRgb* p = reinterpret_cast< QRgb* >( lines[ y ] );
+ TQRgb* p = reinterpret_cast< TQRgb* >( lines[ y ] );
switch ( header.biBitCount )
{
case 1:
@@ -230,7 +230,7 @@ namespace
for ( unsigned y = rec.height; y--; )
{
stream.readRawBytes( reinterpret_cast< char* >( buf ), bpl );
- QRgb* p = reinterpret_cast< QRgb* >( lines[ y ] );
+ TQRgb* p = reinterpret_cast< TQRgb* >( lines[ y ] );
for ( unsigned x = 0; x < rec.width; ++x, ++p )
if ( ( ( buf[ x / 8 ] >> ( 7 - ( x & 0x07 ) ) ) & 1 ) )
*p &= TQRGB_MASK;
diff --git a/kimgio/jp2.cpp b/kimgio/jp2.cpp
index 68075cf96..5b7e4318e 100644
--- a/kimgio/jp2.cpp
+++ b/kimgio/jp2.cpp
@@ -45,7 +45,7 @@ jas_image_t*
read_image( const TQImageIO* io )
{
jas_stream_t* in = 0;
- // for QIODevice's other than TQFile, a temp. file is used.
+ // for TQIODevice's other than TQFile, a temp. file is used.
KTempFile* tempf = 0;
TQFile* qf = 0;
diff --git a/kimgio/pcx.cpp b/kimgio/pcx.cpp
index 7a5c843fa..ea02b67a9 100644
--- a/kimgio/pcx.cpp
+++ b/kimgio/pcx.cpp
@@ -467,7 +467,7 @@ static void writeImage24( TQImage &img, TQDataStream &s, PCXHEADER &header )
for ( unsigned int x=0; x<header.width(); ++x )
{
- QRgb rgb = *p++;
+ TQRgb rgb = *p++;
r_buf[ x ] = tqRed( rgb );
g_buf[ x ] = tqGreen( rgb );
b_buf[ x ] = tqBlue( rgb );
diff --git a/kimgio/pcx.h b/kimgio/pcx.h
index 3bf111773..c72b01733 100644
--- a/kimgio/pcx.h
+++ b/kimgio/pcx.h
@@ -27,7 +27,7 @@ class RGB
public:
RGB() { }
- RGB( const QRgb color )
+ RGB( const TQRgb color )
{
r = tqRed( color );
g = tqGreen( color );
@@ -44,12 +44,12 @@ class Palette
public:
Palette() { }
- void setColor( int i, const QRgb color )
+ void setColor( int i, const TQRgb color )
{
rgb[ i ] = RGB( color );
}
- QRgb color( int i ) const
+ TQRgb color( int i ) const
{
return tqRgb( rgb[ i ].r, rgb[ i ].g, rgb[ i ].b );
}
diff --git a/kimgio/rgb.cpp b/kimgio/rgb.cpp
index cf1f2331a..bdda0959a 100644
--- a/kimgio/rgb.cpp
+++ b/kimgio/rgb.cpp
@@ -120,7 +120,7 @@ bool SGIImage::getRow(uchar *dest)
bool SGIImage::readData(TQImage& img)
{
- QRgb *c;
+ TQRgb *c;
TQ_UINT32 *start = m_starttab;
TQByteArray lguard(m_xsize);
uchar *line = (uchar *)lguard.data();
@@ -134,7 +134,7 @@ bool SGIImage::readData(TQImage& img)
m_pos = m_data.begin() + *start++;
if (!getRow(line))
return false;
- c = (QRgb *)img.scanLine(m_ysize - y - 1);
+ c = (TQRgb *)img.scanLine(m_ysize - y - 1);
for (x = 0; x < m_xsize; x++, c++)
*c = tqRgb(line[x], line[x], line[x]);
}
@@ -148,7 +148,7 @@ bool SGIImage::readData(TQImage& img)
m_pos = m_data.begin() + *start++;
if (!getRow(line))
return false;
- c = (QRgb *)img.scanLine(m_ysize - y - 1);
+ c = (TQRgb *)img.scanLine(m_ysize - y - 1);
for (x = 0; x < m_xsize; x++, c++)
*c = tqRgb(tqRed(*c), line[x], line[x]);
}
@@ -158,7 +158,7 @@ bool SGIImage::readData(TQImage& img)
m_pos = m_data.begin() + *start++;
if (!getRow(line))
return false;
- c = (QRgb *)img.scanLine(m_ysize - y - 1);
+ c = (TQRgb *)img.scanLine(m_ysize - y - 1);
for (x = 0; x < m_xsize; x++, c++)
*c = tqRgb(tqRed(*c), tqGreen(*c), line[x]);
}
@@ -172,7 +172,7 @@ bool SGIImage::readData(TQImage& img)
m_pos = m_data.begin() + *start++;
if (!getRow(line))
return false;
- c = (QRgb *)img.scanLine(m_ysize - y - 1);
+ c = (TQRgb *)img.scanLine(m_ysize - y - 1);
for (x = 0; x < m_xsize; x++, c++)
*c = tqRgba(tqRed(*c), tqGreen(*c), tqBlue(*c), line[x]);
}
@@ -394,12 +394,12 @@ bool SGIImage::scanData(const TQImage& img)
TQCString bufguard(m_xsize);
uchar *line = (uchar *)lineguard.data();
uchar *buf = (uchar *)bufguard.data();
- QRgb *c;
+ TQRgb *c;
unsigned x, y;
uint len;
for (y = 0; y < m_ysize; y++) {
- c = reinterpret_cast<QRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
+ c = reinterpret_cast<TQRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
for (x = 0; x < m_xsize; x++)
buf[x] = intensity(tqRed(*c++));
len = compact(line, buf);
@@ -411,7 +411,7 @@ bool SGIImage::scanData(const TQImage& img)
if (m_zsize != 2) {
for (y = 0; y < m_ysize; y++) {
- c = reinterpret_cast<QRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
+ c = reinterpret_cast<TQRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
for (x = 0; x < m_xsize; x++)
buf[x] = intensity(tqGreen(*c++));
len = compact(line, buf);
@@ -419,7 +419,7 @@ bool SGIImage::scanData(const TQImage& img)
}
for (y = 0; y < m_ysize; y++) {
- c = reinterpret_cast<QRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
+ c = reinterpret_cast<TQRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
for (x = 0; x < m_xsize; x++)
buf[x] = intensity(tqBlue(*c++));
len = compact(line, buf);
@@ -431,7 +431,7 @@ bool SGIImage::scanData(const TQImage& img)
}
for (y = 0; y < m_ysize; y++) {
- c = reinterpret_cast<QRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
+ c = reinterpret_cast<TQRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
for (x = 0; x < m_xsize; x++)
buf[x] = intensity(tqAlpha(*c++));
len = compact(line, buf);
@@ -494,11 +494,11 @@ void SGIImage::writeVerbatim(const TQImage& img)
kdDebug(399) << "writing verbatim data" << endl;
writeHeader();
- QRgb *c;
+ TQRgb *c;
unsigned x, y;
for (y = 0; y < m_ysize; y++) {
- c = reinterpret_cast<QRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
+ c = reinterpret_cast<TQRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
for (x = 0; x < m_xsize; x++)
m_stream << TQ_UINT8(tqRed(*c++));
}
@@ -508,13 +508,13 @@ void SGIImage::writeVerbatim(const TQImage& img)
if (m_zsize != 2) {
for (y = 0; y < m_ysize; y++) {
- c = reinterpret_cast<QRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
+ c = reinterpret_cast<TQRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
for (x = 0; x < m_xsize; x++)
m_stream << TQ_UINT8(tqGreen(*c++));
}
for (y = 0; y < m_ysize; y++) {
- c = reinterpret_cast<QRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
+ c = reinterpret_cast<TQRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
for (x = 0; x < m_xsize; x++)
m_stream << TQ_UINT8(tqBlue(*c++));
}
@@ -524,7 +524,7 @@ void SGIImage::writeVerbatim(const TQImage& img)
}
for (y = 0; y < m_ysize; y++) {
- c = reinterpret_cast<QRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
+ c = reinterpret_cast<TQRgb *>(const_cast<TQImage&>(img).scanLine(m_ysize - y - 1));
for (x = 0; x < m_xsize; x++)
m_stream << TQ_UINT8(tqAlpha(*c++));
}
diff --git a/kimgio/tga.cpp b/kimgio/tga.cpp
index 3a9d88515..65e29a8cf 100644
--- a/kimgio/tga.cpp
+++ b/kimgio/tga.cpp
@@ -262,7 +262,7 @@ namespace { // Private.
uchar * src = image;
for( int y = y_start; y != y_end; y += y_step ) {
- QRgb * scanline = (QRgb *) img.scanLine( y );
+ TQRgb * scanline = (TQRgb *) img.scanLine( y );
if( info.pal ) {
// Paletted.
@@ -377,7 +377,7 @@ KDE_EXPORT void kimgio_tga_write( TQImageIO *io )
for( int y = 0; y < img.height(); y++ )
for( int x = 0; x < img.width(); x++ ) {
- const QRgb color = img.pixel( x, y );
+ const TQRgb color = img.pixel( x, y );
s << TQ_UINT8( tqBlue( color ) );
s << TQ_UINT8( tqGreen( color ) );
s << TQ_UINT8( tqRed( color ) );
diff --git a/kimgio/xcf.h b/kimgio/xcf.h
index d3b4302a9..61216488f 100644
--- a/kimgio/xcf.h
+++ b/kimgio/xcf.h
@@ -103,7 +103,7 @@ private:
TQ_UINT32 tattoo; //!< (unique identifier?)
//! As each tile is read from the file, it is buffered here.
- uchar tile[TILE_WIDTH * TILE_HEIGHT * sizeof(QRgb)];
+ uchar tile[TILE_WIDTH * TILE_HEIGHT * sizeof(TQRgb)];
//! The data from tile buffer is copied to the Tile by this
//! method. Depending on the type of the tile (RGB, Grayscale,
@@ -132,13 +132,13 @@ private:
TQ_INT32 tattoo; //!< (unique identifier?)
TQ_UINT32 unit; //!< Units of The GIMP (inch, mm, pica, etc...)
TQ_INT32 num_colors; //!< number of colors in an indexed image
- TQValueVector<QRgb> palette; //!< indexed image color palette
+ TQValueVector<TQRgb> palette; //!< indexed image color palette
int num_layers; //!< number of layers
Layer layer; //!< most recently read layer
bool initialized; //!< Is the TQImage initialized?
- TQImage image; //!< final QImage
+ TQImage image; //!< final TQImage
XCFImage(void) : initialized(false) {}
};
diff --git a/kimgio/xview.cpp b/kimgio/xview.cpp
index 722eba348..c2ceae05a 100644
--- a/kimgio/xview.cpp
+++ b/kimgio/xview.cpp
@@ -144,15 +144,15 @@ KDE_EXPORT void kimgio_xv_write( TQImageIO *imageio )
int r, g, b;
if ( image.depth() == 32 )
{
- QRgb *data32 = (QRgb*) data;
+ TQRgb *data32 = (TQRgb*) data;
r = tqRed( *data32 ) >> 5;
g = tqGreen( *data32 ) >> 5;
b = tqBlue( *data32 ) >> 6;
- data += sizeof( QRgb );
+ data += sizeof( TQRgb );
}
else
{
- QRgb color = image.color( *data );
+ TQRgb color = image.color( *data );
r = tqRed( color ) >> 5;
g = tqGreen( color ) >> 5;
b = tqBlue( color ) >> 6;
diff --git a/kimgio/xcf.cpp b/kimgio/xcf.cpp
index 1c0bb79d1..dd243bcce 100644
--- a/kimgio/xcf.cpp
+++ b/kimgio/xcf.cpp
@@ -77,8 +77,8 @@ const XCFImageFormat::LayerModes XCFImageFormat::layer_modes[] = {
};
-//! Change a QRgb value's alpha only.
-inline QRgb tqRgba ( QRgb rgb, int a )
+//! Change a TQRgb value's alpha only.
+inline TQRgb tqRgba ( TQRgb rgb, int a )
{
return ((a & 0xff) << 24 | (rgb & TQRGB_MASK));
}
@@ -676,7 +676,7 @@ void XCFImageFormat::assignImageBytes(Layer& layer, uint i, uint j)
for (int k = 0; k < layer.image_tiles[j][i].width(); k++) {
layer.image_tiles[j][i].setPixel(k, l,
tqRgb(tile[0], tile[1], tile[2]));
- tile += sizeof(QRgb);
+ tile += sizeof(TQRgb);
}
}
break;
@@ -686,7 +686,7 @@ void XCFImageFormat::assignImageBytes(Layer& layer, uint i, uint j)
for ( int k = 0; k < layer.image_tiles[j][i].width(); k++ ) {
layer.image_tiles[j][i].setPixel(k, l,
tqRgba(tile[0], tile[1], tile[2], tile[3]));
- tile += sizeof(QRgb);
+ tile += sizeof(TQRgb);
}
}
break;
@@ -696,7 +696,7 @@ void XCFImageFormat::assignImageBytes(Layer& layer, uint i, uint j)
for (int l = 0; l < layer.image_tiles[j][i].height(); l++) {
for (int k = 0; k < layer.image_tiles[j][i].width(); k++) {
layer.image_tiles[j][i].setPixel(k, l, tile[0]);
- tile += sizeof(QRgb);
+ tile += sizeof(TQRgb);
}
}
break;
@@ -714,7 +714,7 @@ void XCFImageFormat::assignImageBytes(Layer& layer, uint i, uint j)
layer.image_tiles[j][i].setPixel(k, l, tile[0]);
layer.alpha_tiles[j][i].setPixel(k, l, tile[1]);
- tile += sizeof(QRgb);
+ tile += sizeof(TQRgb);
}
}
break;
@@ -723,7 +723,7 @@ void XCFImageFormat::assignImageBytes(Layer& layer, uint i, uint j)
/*!
- * The GIMP stores images in a "mipmap"-like hierarchy. As far as the QImage
+ * The GIMP stores images in a "mipmap"-like hierarchy. As far as the TQImage
* is concerned, however, only the top level (i.e., the full resolution image)
* is used.
* \param xcf_io the data stream connected to the XCF image.
@@ -963,7 +963,7 @@ bool XCFImageFormat::loadTileRLE(TQDataStream& xcf_io, uchar* tile, int image_si
while (length-- > 0) {
*data = *xcfdata++;
- data += sizeof(QRgb);
+ data += sizeof(TQRgb);
}
} else {
length += 1;
@@ -988,7 +988,7 @@ bool XCFImageFormat::loadTileRLE(TQDataStream& xcf_io, uchar* tile, int image_si
while (length-- > 0) {
*data = val;
- data += sizeof(QRgb);
+ data += sizeof(TQRgb);
}
}
}
@@ -1071,14 +1071,14 @@ void XCFImageFormat::assignMaskBytes(Layer& layer, uint i, uint j)
for (int l = 0; l < layer.image_tiles[j][i].height(); l++) {
for (int k = 0; k < layer.image_tiles[j][i].width(); k++) {
layer.mask_tiles[j][i].setPixel(k, l, tile[0]);
- tile += sizeof(QRgb);
+ tile += sizeof(TQRgb);
}
}
}
/*!
- * Construct the TQImage which will eventually be returned to the QImage
+ * Construct the TQImage which will eventually be returned to the TQImage
* loader.
*
* There are a couple of situations which require that the TQImage is not
@@ -1320,7 +1320,7 @@ void XCFImageFormat::copyLayerToImage(XCFImage& xcf_image)
void XCFImageFormat::copyRGBToRGB(Layer& layer, uint i, uint j, int k, int l,
TQImage& image, int m, int n)
{
- QRgb src = layer.image_tiles[j][i].pixel(k, l);
+ TQRgb src = layer.image_tiles[j][i].pixel(k, l);
uchar src_a = layer.opacity;
if (layer.type == RGBA_GIMAGE)
@@ -1371,7 +1371,7 @@ void XCFImageFormat::copyGrayToGray(Layer& layer, uint i, uint j, int k, int l,
void XCFImageFormat::copyGrayToRGB(Layer& layer, uint i, uint j, int k, int l,
TQImage& image, int m, int n)
{
- QRgb src = layer.image_tiles[j][i].pixel(k, l);
+ TQRgb src = layer.image_tiles[j][i].pixel(k, l);
uchar src_a = layer.opacity;
image.setPixel(m, n, tqRgba(src, src_a));
}
@@ -1393,7 +1393,7 @@ void XCFImageFormat::copyGrayToRGB(Layer& layer, uint i, uint j, int k, int l,
void XCFImageFormat::copyGrayAToRGB(Layer& layer, uint i, uint j, int k, int l,
TQImage& image, int m, int n)
{
- QRgb src = layer.image_tiles[j][i].pixel(k, l);
+ TQRgb src = layer.image_tiles[j][i].pixel(k, l);
uchar src_a = layer.alpha_tiles[j][i].pixelIndex(k, l);
src_a = INT_MULT(src_a, layer.opacity);
@@ -1474,7 +1474,7 @@ image.setPixel(m, n, src);
void XCFImageFormat::copyIndexedAToRGB(Layer& layer, uint i, uint j, int k, int l,
TQImage& image, int m, int n)
{
- QRgb src = layer.image_tiles[j][i].pixel(k, l);
+ TQRgb src = layer.image_tiles[j][i].pixel(k, l);
uchar src_a = layer.alpha_tiles[j][i].pixelIndex(k, l);
src_a = INT_MULT(src_a, layer.opacity);
@@ -1583,8 +1583,8 @@ void XCFImageFormat::mergeLayerIntoImage(XCFImage& xcf_image)
void XCFImageFormat::mergeRGBToRGB(Layer& layer, uint i, uint j, int k, int l,
TQImage& image, int m, int n)
{
- QRgb src = layer.image_tiles[j][i].pixel(k, l);
- QRgb dst = image.pixel(m, n);
+ TQRgb src = layer.image_tiles[j][i].pixel(k, l);
+ TQRgb dst = image.pixel(m, n);
uchar src_r = tqRed(src);
uchar src_g = tqGreen(src);
@@ -1872,7 +1872,7 @@ void XCFImageFormat::mergeGrayAToGray(Layer& layer, uint i, uint j, int k, int l
void XCFImageFormat::mergeGrayToRGB(Layer& layer, uint i, uint j, int k, int l,
TQImage& image, int m, int n)
{
- QRgb src = layer.image_tiles[j][i].pixel(k, l);
+ TQRgb src = layer.image_tiles[j][i].pixel(k, l);
uchar src_a = layer.opacity;
image.setPixel(m, n, tqRgba(src, src_a));
}
@@ -2034,7 +2034,7 @@ void XCFImageFormat::mergeIndexedAToIndexed(Layer& layer, uint i, uint j, int k,
void XCFImageFormat::mergeIndexedAToRGB(Layer& layer, uint i, uint j, int k, int l,
TQImage& image, int m, int n)
{
- QRgb src = layer.image_tiles[j][i].pixel(k, l);
+ TQRgb src = layer.image_tiles[j][i].pixel(k, l);
uchar src_a = layer.alpha_tiles[j][i].pixelIndex(k, l);
src_a = INT_MULT(src_a, layer.opacity);
@@ -2073,7 +2073,7 @@ void XCFImageFormat::dissolveRGBPixels ( TQImage& image, int x, int y )
for (int k = 0; k < image.width(); k++) {
int rand_val = rand() & 0xff;
- QRgb pixel = image.pixel(k, l);
+ TQRgb pixel = image.pixel(k, l);
if (rand_val > tqAlpha(pixel)) {
image.setPixel(k, l, tqRgba(pixel, 0));